@@ -9,6 +9,9 @@ use std::{
 
 use reqwest::IntoUrl;
 
+#[cfg(feature = "local")]
+pub mod local;
+
 /// A response from the api
 #[derive(serde::Deserialize, Debug, Clone, Hash)]
 pub struct NekosBestResponse {
@@ -149,7 +152,8 @@ impl std::fmt::Display for Category {
     }
 }
 
-pub const BASE_URL: &str = "https://nekos.best";
+pub const API_VERSION: usize = 1;
+pub const BASE_URL: &str = "https://nekos.best/api/v1";
 
 /// Gets a single image, with a supplied client.
 ///
@@ -226,15 +230,15 @@ pub async fn get_details_with_client(
 
     let result = match details_header {
         Some(h) => {
-            let s = h.to_str().expect("Not UTF-8 header");
-            serde_json::from_str::<NekosDetails>(s)?
+            let s = h.to_str().expect("Not ASCII header");
+            serde_json::from_str::<NekosDetailsInternalUrlEncoded>(s)?
         }
         None => return Err(NekosBestError::NotFound),
     };
 
     drop(r);
 
-    Ok(result)
+    Ok(From::from(result))
 }
 
 /// Gets the source of a [`Category::Nekos`] image,
@@ -242,9 +246,7 @@ pub async fn get_details_with_client(
 ///
 /// # Errors
 /// Any errors that can happen, refer to [`NekosBestError`].
-pub async fn get_details(
-    url: impl IntoUrl,
-) -> Result<NekosDetails, NekosBestError> {
+pub async fn get_details(url: impl IntoUrl) -> Result<NekosDetails, NekosBestError> {
     let client = reqwest::Client::new();
 
     get_details_with_client(&client, url).await
@@ -262,7 +264,7 @@ impl TryFrom<String> for UrlEncodedString {
 }
 
 #[derive(serde::Deserialize)]
-struct NekosDetailsInternal {
+struct NekosDetailsInternalUrlEncoded {
     artist_href: UrlEncodedString,
     artist_name: UrlEncodedString,
     source_url: UrlEncodedString,
@@ -272,15 +274,14 @@ struct NekosDetailsInternal {
 /// also returns the source url, the name and a
 /// link to the artist that made it.
 #[derive(serde::Deserialize, Debug, Clone, Hash, PartialEq, Eq, PartialOrd, Ord)]
-#[serde(from = "NekosDetailsInternal")]
 pub struct NekosDetails {
     pub artist_href: String,
     pub artist_name: String,
     pub source_url: String,
 }
 
-impl From<NekosDetailsInternal> for NekosDetails {
-    fn from(d: NekosDetailsInternal) -> Self {
+impl From<NekosDetailsInternalUrlEncoded> for NekosDetails {
+    fn from(d: NekosDetailsInternalUrlEncoded) -> Self {
         Self {
             artist_href: d.artist_href.0,
             artist_name: d.artist_name.0,
